%global major 1
%define libname %mklibname ispcrt %major
%define devname %mklibname -d ispcrt

%global with_snapshot	0
%global date		20190309
%global commit		34da2d23bbf32abf44da11d2cdca595dc7318cec
%global shortcommit	%(c=%{commit}; echo ${c:0:7})

%bcond_with examples

%define rel	1

Name:		ispc
Version:	1.18.0
%if %{with_snapshot}
Release:	%mkrel -c git%{date} %{rel}
%else
Release:	%mkrel %{rel}
%endif
Summary:	C-based SPMD programming language compiler
Group:		Development/C
License:	BSD
URL:		https://ispc.github.io/
%if %{with_snapshot}
Source0:	https://github.com/%{name}/%{name}/archive/%{commit}/%{name}-%{shortcommit}.tar.xz
%else
Source0:	https://github.com/%{name}/%{name}/archive/v%{version}/%{name}-%{version}.tar.xz
%endif
BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	clang-devel
BuildRequires:	doxygen
BuildRequires:	flex
BuildRequires:	git
BuildRequires:	gcc-c++
BuildRequires:	llvm-devel
BuildRequires:	rst2html
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(zlib)

# Upstream only supports these architectures
ExclusiveArch:	x86_64 %{arm64}

# https://fedoraproject.org/wiki/Changes/Stop-Shipping-Individual-Component-Libraries-In-clang-lib-Package
Patch0:		0001-Link-against-libclang-cpp.so.patch

#
# Fix examples path
# From git

#
Patch200:	ispc-1.11.0-examples-path.patch
Source202:	ispc-1.13.0-remove-unsupported-flags.patch

%if ! %{with examples}
Obsoletes:	%{name}-examples < 1.16.1-2
%endif

%description
A compiler for a variant of the C programming language, with extensions for
"single program, multiple data" (SPMD) programming.

%package examples
Summary:        Examples binaries for ispc
Group:          Development/Other

%description examples
This package contains the examples binaries for the ispc SPMD compiler.

%package -n %libname
Summary: Library for ispc
Group: System/Libraries

%description -n %libname
Library for ispc.

%package -n %devname
Group:          Development/Libraries
Summary:	Development files for %{name}
Requires:	%{libname}%{?_isa} = %{version}-%{release}

%description -n %devname
The %{name}-devel package contains libraries and header files for
 applications that use %{name}.
 
%prep
%if %{with_snapshot}
%setup -qn %{name}-%{commit}
%apply_patches
%else
%setup -qn %{name}-%{version}
%apply_patches
%endif

# Use gcc rather clang by default
sed -i 's|set(CMAKE_C_COMPILER "clang")|set(CMAKE_C_COMPILER "gcc")|g' CMakeLists.txt
sed -i 's|set(CMAKE_CXX_COMPILER "clang++")|set(CMAKE_CXX_COMPILER "g++")|g' CMakeLists.txt

# Delete unrecognized command options from gcc-c++
sed -i 's|-Wno-c99-extensions -Wno-deprecated-register||g' CMakeLists.txt

# Suppress warning message as error
sed -i 's| -Werror ||g' CMakeLists.txt

# Fix all Python shebangs recursively in .
%py3_shebang_fix .

%build
%cmake	\
	-DCMAKE_BUILD_TYPE=Release \
	-DCMAKE_INSTALL_PREFIX=%{_prefix} \
	-DCMAKE_EXE_LINKER_FLAGS="%{ldflags} -fPIE" \
	-DISPC_INCLUDE_EXAMPLES=%{?with_examples:ON}%{!?with_examples:OFF} \
	-DISPC_INCLUDE_TESTS=OFF \
	-DISPC_NO_DUMPS=ON \
	-DLEVEL_ZERO_INCLUDE_DIR=%{_includedir} \
	-DLEVEL_ZERO_LIB_LOADER=%{_libddir} \
	-DLLVM_ENABLE_ASSERTIONS=OFF 
%cmake_build

%install
%cmake_install

#Remove static file
rm %{buildroot}%{_libdir}/lib%{name}rt_static.a

%files
%{_bindir}/%{name}
%{_bindir}/check_isa

%if %{with examples}
%files examples
#{_prefix}/lib/ispc/examples
%endif

%files -n %libname
%{_libdir}/lib%{name}rt.so.%{major}*

%files -n %devname
%{_includedir}/%{name}rt/
%{_libdir}/cmake/%{name}rt-%{version}/
%{_libdir}/lib%{name}rt.so


%changelog
* Fri Aug 19 2022 tex - 1.18.0-1pclos2022
- update
